---
title: <span class="badge builder"></span> TableFieldOptions
---
# <span class="badge builder"></span> TableFieldOptions

## Constructor

```python
TableFieldOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.TableFieldOptions
```

### <span class="badge object-method"></span> align

```python
def align(align: common.FieldTextAlignment) -> typing.Self
```

### <span class="badge object-method"></span> cell_options

```python
def cell_options(cell_options: common.TableCellOptions) -> typing.Self
```

### <span class="badge object-method"></span> display_mode

This field is deprecated in favor of using cellOptions

```python
def display_mode(display_mode: common.TableCellDisplayMode) -> typing.Self
```

### <span class="badge object-method"></span> filterable

```python
def filterable(filterable: bool) -> typing.Self
```

### <span class="badge object-method"></span> hidden

?? default is missing or false ??

```python
def hidden(hidden: bool) -> typing.Self
```

### <span class="badge object-method"></span> hide_header

Hides any header for a column, useful for columns that show some static content or buttons.

```python
def hide_header(hide_header: bool) -> typing.Self
```

### <span class="badge object-method"></span> inspect

```python
def inspect(inspect: bool) -> typing.Self
```

### <span class="badge object-method"></span> min_width

```python
def min_width(min_width: float) -> typing.Self
```

### <span class="badge object-method"></span> width

```python
def width(width: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TableFieldOptions](./object-TableFieldOptions.md)
